/**********************************************************************************************************************
 * DISCLAIMER
 * This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
 * other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
 * applicable laws, including copyright laws.
 * THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
 * THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
 * EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
 * SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO
 * THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
 * this software. By using this software, you agree to the additional terms and conditions found by accessing the
 * following link:
 * http://www.renesas.com/disclaimer
 *
 * Copyright (C) 2019 Renesas Electronics Corporation. All rights reserved.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * File Name    : r_tm_api.c
 * Version      : 1.10
 * Description  : The programs of Trusted Memory areas.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * History : DD.MM.YYYY Version  Description
 *         : 01.04.2015 1.00     First Release
 *         : 26.04.2019 1.10     Second Release
 *********************************************************************************************************************/

/**********************************************************************************************************************
 Includes   <System Includes> , "Project Includes"
 *********************************************************************************************************************/
#include <stdint.h>
#include <stdbool.h>
#include "iodefine.h"
#include "r_tm_api.h"

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
#pragma section _TM
const uint8_t g_tm_led_table[] = {
    0x01,
    0x02,
    0x04,
    0x08
};

const uint8_t g_led_pattern_num = 0x04;

/* **** TM function table1 **** */
void (* const tm_func_table1[])(void) = {
    (void (*)())(__sectop("P_TM_FUNC_01")),           /* R_TM_PortInit */
    (void (*)())(__sectop("P_TM_FUNC_03")),           /* R_TM_LedOff */
};

/* **** TM function table2 **** */
void (* const tm_func_table2[])(uint8_t argument) = {
    (void (*)(uint8_t))(__sectop("P_TM_FUNC_02")),    /* R_TM_SetLedPattern */
};

/*******************************************************************************
Private variables and functions
*******************************************************************************/
static void tm_led_on(void);

#pragma section _TM_FUNC_01
/*******************************************************************************
* Outline      : Initialization of I/O ports
* Header       : r_tm_api.h
* Function Name: R_TM_PortInit
* Description  : Initialize I/O ports.
* Arguments    : none
* Return Value : none
*******************************************************************************/
void R_TM_PortInit(void)
{
    /* ---- Initialize LEDs ---- */

    /* Set port output data - LEDs OFF */
    LED0_REG_PODR = LED_OFF;
    LED1_REG_PODR = LED_OFF;
    LED2_REG_PODR = LED_OFF;
    LED3_REG_PODR = LED_OFF;

    /* Set port direction - Output */
    LED0_REG_PDR = 1;
    LED1_REG_PDR = 1;
    LED2_REG_PDR = 1;
    LED3_REG_PDR = 1;

    /* Set port mode - Use pin as general I/O port */
    LED0_REG_PMR = 0;
    LED1_REG_PMR = 0;
    LED2_REG_PMR = 0;
    LED3_REG_PMR = 0;
} /* End of function R_TM_PortInit() */

#pragma section _TM_FUNC_02
/*******************************************************************************
* Outline      : Set LED pattern
* Header       : r_tm_api.h
* Function Name: R_TM_SetLedPattern
* Description  : Output the LED pattern.
                 In the case of LED pattern is "0x00", Turn on the all LED.
* Arguments    : uint8_t pattern - LED pattern
* Return Value : none
*******************************************************************************/
void R_TM_SetLedPattern(uint8_t pattern)
{
    if (0x00 == pattern)
    {
        tm_led_on();
    }
    else
    {
        if (0x01 == (pattern & 0x01))
        {
            LED0_REG_PODR = LED_ON;
        }
        else
        {
            LED0_REG_PODR = LED_OFF;
        }

        if (0x02 == (pattern & 0x02))
        {
            LED1_REG_PODR = LED_ON;
        }
        else
        {
            LED1_REG_PODR = LED_OFF;
        }

        if (0x04 == (pattern & 0x04))
        {
            LED2_REG_PODR = LED_ON;
        }
        else
        {
            LED2_REG_PODR = LED_OFF;
        }

        if (0x08 == (pattern & 0x08))
        {
            LED3_REG_PODR = LED_ON;
        }
        else
        {
            LED3_REG_PODR = LED_OFF;
        }
    }
} /* End of function R_TM_SetLedPattern() */

#pragma section _TM_FUNC_03
/*******************************************************************************
* Outline      : Turn off the all LED
* Header       : r_tm_api.h
* Function Name: R_TM_LedOff
* Description  : Turn off the all LED
* Arguments    : none
* Return Value : none
*******************************************************************************/
void R_TM_LedOff(void)
{
    LED0_REG_PODR = LED_OFF;
    LED1_REG_PODR = LED_OFF;
    LED2_REG_PODR = LED_OFF;
    LED3_REG_PODR = LED_OFF;
} /* End of function R_TM_LedOff() */

#pragma section _TM
/*******************************************************************************
* Outline      : Turn on the all LED
* Header       : r_tm_api.h
* Function Name: tm_led_on
* Description  : Turn on the all LED
* Arguments    : none
* Return Value : none
*******************************************************************************/
static void tm_led_on(void)
{
    LED0_REG_PODR = LED_ON;
    LED1_REG_PODR = LED_ON;
    LED2_REG_PODR = LED_ON;
    LED3_REG_PODR = LED_ON;
} /* End of function tm_led_on() */

/* End of File */

