/**********************************************************************************************************************
 * DISCLAIMER
 * This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products. No
 * other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
 * applicable laws, including copyright laws.
 * THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
 * THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM
 * EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES
 * SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO
 * THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability of
 * this software. By using this software, you agree to the additional terms and conditions found by accessing the
 * following link:
 * http://www.renesas.com/disclaimer
 *
 * Copyright (C) 2019 Renesas Electronics Corporation. All rights reserved.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * File Name    : main.c
 * Version      : 1.10
 * Description  : Sample program for Trusted Memory.
 *********************************************************************************************************************/
/**********************************************************************************************************************
 * History : DD.MM.YYYY Version  Description
 *         : 01.04.2015 1.00     First Release
 *         : 26.04.2019 1.10     Second Release
 *********************************************************************************************************************/

/**********************************************************************************************************************
 Includes   <System Includes> , "Project Includes"
 *********************************************************************************************************************/
#include <machine.h>
#include <stdint.h>
#include <stdbool.h>
#include "iodefine.h"
#include "r_init_clock.h"
#include "r_init_port_initialize.h"
#include "r_init_stop_module.h"

/**********************************************************************************************************************
Macro definitions
 *********************************************************************************************************************/
/* tm_func_table1 */
#define R_TM_PORT_INIT    (0)          /* 0xFFFE0000 - void R_TM_PortInit(void) */
#define R_TM_LED_OFF      (1)          /* 0xFFFE0200 - void R_TM_LedOff(void) */

/* tm_func_table2 */
#define R_TM_SET_LED_PATTERN    (0)    /* 0xFFFE0100 - void R_TM_SetLedPattern(uint8_t pattern)) */

/*******************************************************************************
Imported global variables and functions (from other files)
*******************************************************************************/
extern const uint8_t g_led_pattern_num;
extern const uint8_t g_tm_led_table[];
extern void (* const tm_func_table1[])(void);
extern void (* const tm_func_table2[])(uint8_t);

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void main(void);

/*******************************************************************************
Private variables and functions
*******************************************************************************/
static void led_control(const uint8_t * table, const uint8_t pattern_num);

/*******************************************************************************
* Outline      : Main processing
* Header       : none
* Function Name: main
* Description  : After initialization, access to the Trusted Memory areas.(LED lighting process.)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{
    uint8_t  cnt;

    /* **** Initialize MCU **** */

    /* ---- Disable maskable interrupts ---- */
    clrpsw_i();

    /* ---- Stopping the peripherals which start operations  ---- */
    R_INIT_StopModule();

    /* ---- Initialization of the non-existent ports ---- */
    R_INIT_Port_Initialize();

    /* ---- Initialization of the clock ---- */
    R_INIT_Clock();

    /* ==== Enable maskable interrupts ==== */
    setpsw_i();

    /* ==== Initialize LED ports ==== */
    tm_func_table1[R_TM_PORT_INIT]();

    /* ==== LEDs ON (Use the table of the TM area outside) ==== */
    for (cnt = 0; cnt < 0x05; cnt++)
    {
        led_control(g_tm_led_table, g_led_pattern_num);
    }

    /* ==== LEDs OFF ==== */
    tm_func_table1[R_TM_LED_OFF]();

    while(1)
    {
        /* Main loop */
        nop();
    }
} /* End of function main() */

/*******************************************************************************
* Outline      : LED control
* Header       : none
* Function Name: led_control
* Description  : Output the LED pattern of LED table in order.
* Arguments    : const uint8_t *table      - LED table
                 const uint8_t pattern_num - LED pattern number
* Return Value : none
*******************************************************************************/
static void led_control(const uint8_t * table, const uint8_t pattern_num)
{
    uint8_t  num;
    volatile uint32_t wait_cnt;

    for (num = 0; num < pattern_num; num++)
    {
        /* ==== LEDs ON ==== */
        tm_func_table2[R_TM_SET_LED_PATTERN](*table);
        table++;

        for (wait_cnt = 0; wait_cnt < 0x00800000; wait_cnt++)
        {
            /* LED_wait */
        }
    }

} /* End of function led_control() */

/* End of File */

