/*******************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only
* intended for use with Renesas products. No other uses are authorized. This
* software is owned by Renesas Electronics Corporation and is protected under
* all applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
* THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT
* LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE
* AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
* TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS
* ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE
* FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR
* ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
* BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software
* and to discontinue the availability of this software. By using this software,
* you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2017-2019 Renesas Electronics Corporation. All rights reserved.
*******************************************************************************/
/*******************************************************************************
* System Name  : RX65N group, RX651 group initialization example
* File Name    : r_init_port_initialize.h
* Version      : Ver 1.10
* Device       : R5F565NEDDFC(RX65N Group)
* Abstract     : Program example of RX65N group, RX651 group initialization
* Tool-Chain   : e2 studio Version 7.4.0
*              : C/C++ Compiler Package for RX Family (V.3.01.00)
* OS           : not use
* H/W Platform : Renesas Starter Kit+ for RX65N-2MB
* Description  : Initialization of non-existent ports.
* Limitation   : none
*******************************************************************************/
/*******************************************************************************
* History      : DD.MM.YYYY Version  Description
*              : 02.10.2017 1.00     First Release
*              : 31.05.2019 1.10     Add PDR macro definitions for 64-pin MCU pins.
*******************************************************************************/

/* Guards against multiple inclusion */
#ifndef R_INIT_PORT_INITIALIZE_H
#define R_INIT_PORT_INITIALIZE_H

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define PIN_SIZE    (176)

#if ((PIN_SIZE == 177) || (PIN_SIZE == 176))
 #define DEF_P0PDR        (0x50)        /* non-existent pin: P04 P06 */
 #define DEF_P1PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P2PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P3PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P4PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P5PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P6PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P7PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P8PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P9PDR        (0x00)        /* non-existent pin: none */
 #define DEF_PAPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PBPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PCPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PDPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PEPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PFPDR        (0xC0)        /* non-existent pin: PF6 PF7 */
 #define DEF_PGPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PJPDR        (0xD0)        /* non-existent pin: PJ4 PJ6 PJ7 */

#elif ((PIN_SIZE == 145) || (PIN_SIZE == 144))
 #define DEF_P0PDR        (0x50)        /* non-existent pin: P04 P06 */
 #define DEF_P1PDR        (0x03)        /* non-existent pin: P10 P11 */
 #define DEF_P2PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P3PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P4PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P5PDR        (0x80)        /* non-existent pin: P57 */
 #define DEF_P6PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P7PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P8PDR        (0x30)        /* non-existent pin: P84 P85 */
 #define DEF_P9PDR        (0xF0)        /* non-existent pin: P94 P95 P96 P97 */
 #define DEF_PAPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PBPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PCPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PDPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PEPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PFPDR        (0xDF)        /* non-existent pin: PF0 PF1 PF2 PF3 PF4 PF6 PF7 */
 #define DEF_PGPDR        (0xFF)        /* non-existent pin: PG0 PG1 PG2 PG3 PG4 PG5 PG6 PG7 */
 #define DEF_PJPDR        (0xD7)        /* non-existent pin: PJ0 PJ1 PJ2 PJ4 PJ6 PJ7 */

#elif (PIN_SIZE == 100)
 #define DEF_P0PDR        (0x5F)        /* non-existent pin: P00 P01 P02 P03 P04 P06 */
 #define DEF_P1PDR        (0x03)        /* non-existent pin: P10 P11 */
 #define DEF_P2PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P3PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P4PDR        (0x00)        /* non-existent pin: none */
 #define DEF_P5PDR        (0xC0)        /* non-existent pin: P56 P57 */
 #define DEF_P6PDR        (0xFF)        /* non-existent pin: P60 P61 P62 P63 P64 P65 P66 P67 */
 #define DEF_P7PDR        (0xFF)        /* non-existent pin: P70 P71 P72 P73 P74 P75 P76 P77 */
 #define DEF_P8PDR        (0xFF)        /* non-existent pin: P80 P81 P82 P83 P84 P85 P86 P87 */
 #define DEF_P9PDR        (0xFF)        /* non-existent pin: P90 P91 P92 P93 P94 P95 P96 P97 */
 #define DEF_PAPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PBPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PCPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PDPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PEPDR        (0x00)        /* non-existent pin: none */
 #define DEF_PFPDR        (0xFF)        /* non-existent pin: PF0 PF1 PF2 PF3 PF4 PF5 PF6 PF7 */
 #define DEF_PGPDR        (0xFF)        /* non-existent pin: PG0 PG1 PG2 PG3 PG4 PG5 PG6 PG7 */
 #define DEF_PJPDR        (0xF7)        /* non-existent pin: PJ0 PJ1 PJ2 PJ4 PJ5 PJ6 PJ7 */

#elif (PIN_SIZE == 64)
 #define DEF_P0PDR        (0xDF)        /* non-existent pin: P00 P01 P02 P03 P04 P06 P07 */
 #define DEF_P1PDR        (0x33)        /* non-existent pin: P10 P11 P14 P15 */
 #define DEF_P2PDR        (0x3F)        /* non-existent pin: P20 P21 P22 P23 P24 P25 */
 #define DEF_P3PDR        (0x0C)        /* non-existent pin: P32 P33 */
 #define DEF_P4PDR        (0xF0)        /* non-existent pin: P44 P45 P46 P47 */
 #define DEF_P5PDR        (0xF7)        /* non-existent pin: P50 P51 P52 P54 P55 P56 P57 */
 #define DEF_P6PDR        (0xFF)        /* non-existent pin: P60 P61 P62 P63 P64 P65 P66 P67 */
 #define DEF_P7PDR        (0xFF)        /* non-existent pin: P70 P71 P72 P73 P74 P75 P76 P77 */
 #define DEF_P8PDR        (0xFF)        /* non-existent pin: P80 P81 P82 P83 P84 P85 P86 P87 */
 #define DEF_P9PDR        (0xFF)        /* non-existent pin: P90 P91 P92 P93 P94 P95 P96 P97 */
 #define DEF_PAPDR        (0x29)        /* non-existent pin: PA0 PA3 PA5 */
 #define DEF_PBPDR        (0x1F)        /* non-existent pin: PB0 PB1 PB2 PB3 PB4 */
 #define DEF_PCPDR        (0x0C)        /* non-existent pin: PC2 PC3 */
 #define DEF_PDPDR        (0x03)        /* non-existent pin: PD0 PD1 */
 #define DEF_PEPDR        (0x38)        /* non-existent pin: PE3 PE4 PE5 */
 #define DEF_PFPDR        (0xFF)        /* non-existent pin: PF0 PF1 PF2 PF3 PF4 PF5 PF6 PF7 */
 #define DEF_PGPDR        (0xFF)        /* non-existent pin: PG0 PG1 PG2 PG3 PG4 PG5 PG6 PG7 */
 #define DEF_PJPDR        (0xFF)        /* non-existent pin: PJ0 PJ1 PJ2 PJ3 PJ4 PJ5 PJ6 PJ7 */

#else
#endif

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void R_INIT_Port_Initialize(void);

#endif /* R_INIT_PORT_INITIALIZE_H */

/* End of File */
